==> haskell-tasty-quickcheck-0.10.1-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10.1
id: tasty-quickcheck-0.10.1-DTUGl6Qkb7YHyQGVsCdkDx
key: tasty-quickcheck-0.10.1-DTUGl6Qkb7YHyQGVsCdkDx
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: a197ae51a13a829ec3117f43db753ec6
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-quickcheck-0.10.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-quickcheck-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-quickcheck-0.10.1
hs-libraries: HStasty-quickcheck-0.10.1-DTUGl6Qkb7YHyQGVsCdkDx
depends:
    QuickCheck-2.13.2-26sILnMT1dV6Y2IUujSwGD base-4.12.0.0
    optparse-applicative-0.15.1.0-3zohG31eF19CsmDcrOZBbb
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-HVtsfsVGsB3ReS9DqXVTz
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-quickcheck-0.10.1-17-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-quickcheck.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-quickcheck
version: 0.10.1
id: tasty-quickcheck-0.10.1-GQC9wJlIOQmHRaV6K9MpVy
key: tasty-quickcheck-0.10.1-GQC9wJlIOQmHRaV6K9MpVy
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: QuickCheck support for the Tasty test framework.
description:
    QuickCheck support for the Tasty test framework.
category: Testing
abi: 7853feb136e9d4e320e625a5950c2315
exposed: True
exposed-modules:
    Test.Tasty.QuickCheck
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-quickcheck-0.10.1
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-quickcheck-0.10.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-quickcheck-0.10.1
hs-libraries: HStasty-quickcheck-0.10.1-GQC9wJlIOQmHRaV6K9MpVy
depends:
    QuickCheck-2.13.2-8Fp36mG21e67uRy7VcQZNU base-4.12.0.0
    optparse-applicative-0.15.1.0-3zohG31eF19CsmDcrOZBbb
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
    tasty-1.2.3-HVtsfsVGsB3ReS9DqXVTz
haddock-interfaces: /usr/share/doc/haskell-tasty-quickcheck/html/tasty-quickcheck.haddock
haddock-html: /usr/share/doc/haskell-tasty-quickcheck/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
